<!DOCTYPE html>
<html lang="en">

    <head>
        <title>Bootstrap Budget!</title>

        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1">

        <link rel="shortcut icon" href="{{url_for('static', filename='images/favicon.ico')}}">

        <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
        
        <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
        <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.16.0/umd/popper.min.js"></script>
        <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    </head>

    <body>

        <nav class="navbar navbar-dark bg-dark navbar-expand-xl">
            <a class="navbar-brand" href="#">
                <img src="{{url_for('static', filename='images/bootstrap-logo-ffffff-v2.png')}}" width="204" height="28" alt="">
            </a>
        </nav>

        <div class="container my-5">

            <div class="jumbotron">
                <h2>Welcome to Bootstrap Budget!</h2>
                <p>This site is currently under development. In the meantime, check out these <a href='https://alternativeto.net/software/quicken/'>other budgeting tools</a> if you're looking for something now!</p>
                <p><a class="btn btn-primary btn-large" href="https://github.com/baphil8649/bootstrap-budget">Learn more</a></p>
            </div>
        
        </div>

    </body>

</html>